@@ -11,8 +11,11 @@ purpose of these is to simplify data access by proving an interface similar to t
 of netcdf4-python.
 """
 
-from .gini import *  # noqa
-from .nexrad import *  # noqa
+from .gini import *  # noqa: F403
+from .nexrad import *  # noqa: F403
+from .upperair import *  # noqa: F403
+
 __all__ = []
 __all__.extend(gini.__all__)  # pylint: disable=undefined-variable
 __all__.extend(nexrad.__all__)  # pylint: disable=undefined-variable
+__all__.extend(upperair.__all__)  # pylint: disable=undefined-variable
