@@ -10,7 +10,7 @@ from matplotlib.axes import Axes
 from matplotlib.collections import LineCollection
 from matplotlib.patches import Circle
 from matplotlib.projections import register_projection
-from matplotlib.ticker import ScalarFormatter, MultipleLocator
+from matplotlib.ticker import MultipleLocator, NullFormatter, ScalarFormatter
 from .util import colored_line
 from ..calc import dry_lapse, moist_lapse, dewpoint, vapor_pressure
 from ..units import units
@@ -20,77 +20,96 @@ from ..package_tools import Exporter
 exporter = Exporter(globals())
 
 
-# The sole purpose of this class is to look at the upper, lower, or total
-# interval as appropriate and see what parts of the tick to draw, if any.
 class SkewXTick(maxis.XTick):
-    def draw(self, renderer):
-        if not self.get_visible():
-            return
-        renderer.open_group(self.__name__)
+    r"""
+    This class adds to the standard :class:`matplotlib.axis.XTick` dynamic checking
+    for whether a top or bottom tick is actually within the data limits at that part
+    and draw as appropriate. It also performs similar checking for gridlines.
+    """
+    def _need_lower(self):
+        return transforms.interval_contains(self.axes.lower_xlim, self.get_loc())
 
-        lower_interval = self.axes.xaxis.lower_interval
-        upper_interval = self.axes.xaxis.upper_interval
+    def _need_upper(self):
+        return transforms.interval_contains(self.axes.upper_xlim, self.get_loc())
 
-        if self.gridOn and transforms.interval_contains(
-                self.axes.xaxis.get_view_interval(), self.get_loc()):
-            self.gridline.draw(renderer)
+    @property
+    def gridOn(self):
+        return (self._gridOn and transforms.interval_contains(self.get_view_interval(),
+                                                              self.get_loc()))
 
-        if transforms.interval_contains(lower_interval, self.get_loc()):
-            if self.tick1On:
-                self.tick1line.draw(renderer)
-            if self.label1On:
-                self.label1.draw(renderer)
+    @gridOn.setter
+    def gridOn(self, value):
+        self._gridOn = value
 
-        if transforms.interval_contains(upper_interval, self.get_loc()):
-            if self.tick2On:
-                self.tick2line.draw(renderer)
-            if self.label2On:
-                self.label2.draw(renderer)
+    @property
+    def tick1On(self):
+        return self._tick1On and self._need_lower()
 
-        renderer.close_group(self.__name__)
+    @tick1On.setter
+    def tick1On(self, value):
+        self._tick1On = value
+
+    @property
+    def label1On(self):
+        return self._label1On and self._need_lower()
+
+    @label1On.setter
+    def label1On(self, value):
+        self._label1On = value
+
+    @property
+    def tick2On(self):
+        return self._tick2On and self._need_upper()
+
+    @tick2On.setter
+    def tick2On(self, value):
+        self._tick2On = value
+
+    @property
+    def label2On(self):
+        return self._label2On and self._need_upper()
+
+    @label2On.setter
+    def label2On(self, value):
+        self._label2On = value
+
+    def get_view_interval(self):
+        return self.axes.xaxis.get_view_interval()
 
 
-# This class exists to provide two separate sets of intervals to the tick,
-# as well as create instances of the custom tick
 class SkewXAxis(maxis.XAxis):
-    def __init__(self, *args, **kwargs):
-        maxis.XAxis.__init__(self, *args, **kwargs)
-        self.upper_interval = 0.0, 1.0
-
+    r"""
+    This class exists to force the use of our custom :class:`SkewXTick` as well
+    as provide a custom value for interview that combines the extents of the
+    upper and lower x-limits from the axes.
+    """
     def _get_tick(self, major):
         return SkewXTick(self.axes, 0, '', major=major)
 
-    @property
-    def lower_interval(self):
-        return self.axes.viewLim.intervalx
-
     def get_view_interval(self):
-        return self.upper_interval[0], self.axes.viewLim.intervalx[1]
+        return self.axes.upper_xlim[0], self.axes.lower_xlim[1]
 
 
-# This class exists to calculate the separate data range of the
-# upper X-axis and draw the spine there. It also provides this range
-# to the X-axis artist for ticking and gridlines
 class SkewSpine(mspines.Spine):
+    r"""
+    This class exists to use the separate x-limits from the axes to properly
+    locate the spine.
+    """
     def _adjust_location(self):
-        trans = self.axes.transDataToAxes.inverted()
-        if self.spine_type == 'top':
-            yloc = 1.0
-        else:
-            yloc = 0.0
-        left = trans.transform_point((0.0, yloc))[0]
-        right = trans.transform_point((1.0, yloc))[0]
-
         pts = self._path.vertices
-        pts[0, 0] = left
-        pts[1, 0] = right
-        self.axis.upper_interval = (left, right)
+        if self.spine_type == 'top':
+            pts[:, 0] = self.axes.upper_xlim
+        else:
+            pts[:, 0] = self.axes.lower_xlim
 
 
-# This class handles registration of the skew-xaxes as a projection as well
-# as setting up the appropriate transformations. It also overrides standard
-# spines and axes instances as appropriate.
 class SkewXAxes(Axes):
+    r"""
+    This class handles registration of the skew-xaxes as a projection as well as setting up
+    the appropriate transformations. It also makes sure we use our instances for spines
+    and x-axis: :class:`SkewSpine` and :class:`SkewXAxis`. It provides properties to
+    facilitate finding the x-limits for the bottom and top of the plot as well.
+    """
     # The projection must specify a name.  This will be used be the
     # user to select the projection, i.e. ``subplot(111,
     # projection='skewx')``.
@@ -145,6 +164,17 @@ class SkewXAxes(Axes):
             transforms.IdentityTransform()) +
             transforms.Affine2D().skew_deg(self.rot, 0)) + self.transAxes
 
+    @property
+    def lower_xlim(self):
+        r"The data limits for the x-axis along the bottom of the axes"
+        return self.axes.viewLim.intervalx
+
+    @property
+    def upper_xlim(self):
+        r"The data limits for the x-axis along the top of the axes"
+        return self.transDataToAxes.inverted().transform([[0., 1.], [1., 1.]])[:, 0]
+
+
 # Now register the projection with matplotlib so the user can select
 # it.
 register_projection(SkewXAxes)
@@ -234,6 +264,7 @@ class SkewT(object):
         # Disables the log-formatting that comes with semilogy
         self.ax.yaxis.set_major_formatter(ScalarFormatter())
         self.ax.yaxis.set_major_locator(MultipleLocator(100))
+        self.ax.yaxis.set_minor_formatter(NullFormatter())
         if not self.ax.yaxis_inverted():
             self.ax.invert_yaxis()
 
